import {Component, EventEmitter, inject, Output} from '@angular/core';
import {Show} from '../../model/show';
import {FormsModule} from '@angular/forms';
import {ShowService} from '../../services/show.service';
import {Observable} from 'rxjs';
import {AsyncPipe} from '@angular/common';
import {deleteDoc, doc, Firestore, updateDoc} from '@angular/fire/firestore';

@Component({
  selector: 'app-show-list',
  standalone: true,
  imports: [
    FormsModule,
    AsyncPipe
  ],
  templateUrl: './show-list.component.html',
  styleUrl: './show-list.component.css'
})
export class ShowListComponent {
  showService: ShowService = inject(ShowService);
  fireStore: Firestore = inject(Firestore);
  private seriesCollection = 'table_show';
  shows: Observable<Show[]> = this.showService.getShows();

  @Output() selectedShow = new EventEmitter<Show>();
  editShow: Show = new Show(0, "");

  showDetails(show: Show) {
    this.selectedShow.emit(show);
  }

  edit(show: Show) {
    this.editShow = show;
  }

  saveEdit() {
    this.updateShow(this.editShow);

    this.editShow = new Show(0, "");
  }

  updateShow(show: Show) {
    const showDocRef = doc(this.fireStore, `${this.seriesCollection}/${show.uid}`);
    updateDoc(showDocRef, {id: show.uid, title: show.title,});
  }

  delete(show: Show) {
    const showDocRef = doc(this.fireStore, `${this.seriesCollection}/${show.uid}`);
    deleteDoc(showDocRef);
  }

  isToEdit(show: Show): boolean {
    if (!this.editShow) {
      return false;
    } else {
      return this.editShow === show;
    }
  }
}
